@@ -11,7 +11,7 @@ use 5.006;
 
 use strict;
 use warnings;
-our $VERSION = '7.33_02';
+our $VERSION = '7.33_03';
 $VERSION = eval $VERSION;
 
 use ExtUtils::MakeMaker::Config;
@@ -58,8 +58,9 @@ sub _unix_os2_ext {
     my ( $found ) = 0;
 
     if ( $^O eq 'darwin' or $^O eq 'next' )  {
-        # 'escape' Mach-O ld -framework flags, so they aren't dropped later on
+        # 'escape' Mach-O ld -framework and -F flags, so they aren't dropped later on
         $potential_libs =~ s/(^|\s)(-(?:weak_|reexport_|lazy_)?framework)\s+(\S+)/$1-Wl,$2 -Wl,$3/g;
+        $potential_libs =~ s/(^|\s)(-F)\s*(\S+)/$1-Wl,$2 -Wl,$3/g;
     }
 
     foreach my $thislib ( split ' ', $potential_libs ) {
