@@ -1,7 +1,7 @@
 package ExtUtils::MM_Any;
 
 use strict;
-our $VERSION = '7.33_02';
+our $VERSION = '7.33_03';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -2909,7 +2909,7 @@ sub libscan {
 
     if ($path =~ m<^README\.pod$>i) {
         warn "WARNING: Older versions of ExtUtils::MakeMaker may errantly install $path as part of this distribution. It is recommended to avoid using this path in CPAN modules.\n"
-          unless $self->{PERL_CORE};
+          unless $ENV{PERL_CORE};
         return '';
     }
 
